%
%  This script is identical to getplotsoundv.m, but it also calculates the
%  density temperature of a sample lifted through an entraining plume. In
%  its current configuration, the algorithm first calculates the
%  temperature and specific humidity of a sample raised
%  pseudo-adiabatically, but using the ice phase at temperatures below 0 C.
%  It then dilutes the entropy of the plume using a classical plume model
%  with an inverse-z-dependent entrainment coefficient, which can be set
%  below. 
%-----------------------------------------------------------------------
lambda=0.35;    % Entrainment parameter 
%------------------------------------------------------------------------
Lv=2.555e6;
Lf=3.34e5;
ci=2100;
%
place=input('Enter 5-digit station ID or place name (in single quotations) ');
if max(size(place)) > 1
    [u,states,nations,status]=getids(place);
    if status == 0
        disp(' ')
        disp('No such place')
        return
    end    
    usize=max(size(u));
    if usize > 1
        disp(' ')
        disp('Possible station numbers:')
        for i=1:usize
            disp([num2str(u(i)),char(' '),char(states(i)),char(' '),char(nations(i))])
        end    
        disp(' ')
        station_id=input('Which one do you want? (5-digit identifier) ');
    else
        station_id=u;
    end
else
    station_id=place;
end    
A=input('Enter year, month, day,GMT time (e.g. [2014 7 3 6])');
year=A(1);
month=A(2);
day=A(3);
hour=A(4);
%
[data,header,status] = getsounding(station_id,year,month,day,hour);
if status == 0
    disp('No data for this station and time')
    return
end    
%
success=skewtv(data(:,1),data(:,3),data(:,5)/100);
%
titstring=['Station ',num2str(station_id),'  ',num2str(year),'/', ...
    num2str(month),'/',num2str(day),'/', num2str(hour)];
title(titstring)
%
a=10;
if exist('g3') && ishandle(g3) %#ok<EXIST>
    delete(g3)
end
while a > 0
    pideal=input('Enter best pressure to reversibly lift parcel from (0 to stop)');
    if pideal < 100
        break
    end    
    if exist('g1') && ishandle(g1) %#ok<EXIST>
        delete(g1)
        delete(g2)
        delete(g3)
    end
    [~,ibest]=min(abs(data(:,1)-pideal));
    p0=data(ibest,1);
    T0=273.15+data(ibest,3);
    q0=0.001.*data(ibest,6);
    if isnan(T0) || isnan(q0)
        ibest=ibest+1;
        p0=data(ibest,1);
        if p0 < 500
            disp(' ')
            disp('Could not find viable parcel level')
            return
        end    
        T0=273.15+data(ibest,3);
        q0=0.001.*data(ibest,6);
    end
    plift=data(ibest:end,1);
    [ Tlift,qslift] = svinvert( T0,q0,p0,plift );
    Trowlift=Tlift.*(1+qslift/0.622)./(1+q0)-273.15;
    [ Tliftpa,qsliftpa,qi] = svinvertpai( T0,q0,p0,plift );
    Trowliftpa=Tliftpa.*(1+qsliftpa/0.622)./(1+qsliftpa+qi)-273.15;
    %
    Tz=Trowlift'-30.*log(0.001.*plift);
    Tzpa=Trowliftpa'-30.*log(0.001.*plift);
    hold on
    g1=plot(Tz,plift,'.b','markersize',12);
    g2=plot(Tzpa,plift,'--r','linewidth',1.5);
    titstring2=[titstring,'; Parcel lifted from ',char(num2str(plift(1))),' hPa']; 
    title(titstring2)
    %
    % Now calculate entropy of entraining plume
    %
    mlift=max(size(plift));
    p=plift;
    T=273.15+data(ibest:end,3);
    Tp=T;
    q=0.001.*data(ibest:end,6);
    qp=q;
    Tv=T.*(1+q./0.622)./(1+q)-273.15;
    e=p.*q./(q+0.622);
    Tc=T-273.15;
    if Tc > 0
        es=6.112*exp(17.67*Tc./(243.5+Tc));
        qi=0;
    else
        es=exp(23.33086-6111.72784./T+0.15215*log(T));
        qi=0.622*(6.112/(500-6.112)-es./(p-es));
        qi=max(qi,0);
    end    
    rh=e./es;
    rh=min(rh,1);
    rh=max(rh,0.1);
    %Lv=2.555e6+0.5e6*min(max(270-T,0),1);
    s=(1005+qi.*ci).*log(T/290)-287*log(0.001*p)+Lv.*q./T-Lf.*qi./T-461*q.*log(rh);
    sp=s;
    z=zeros(1,mlift);
    qp(1)=q0;
    qps=zeros(1,mlift);
    qps(1)=0.622*es(1)./(p(1)-es(1));
    for i=2:mlift
        z(i)=z(i-1)+287*(546.3+Tv(i)+Tv(i-1))*(p(i-1)-p(i))/(9.8*(p(i-1)+p(i)));
        lamdelz=lambda.*100.*(p(i-1)-p(i))./(9.8*(z(i)+z(i-1)));
        sp(i)=(sp(i-1)*(1-lamdelz)+lamdelz*(s(i)+s(i-1)))/(1+lamdelz);
        [Tp(i),qps(i)]=sinvert(sp(i),p(i));
        qp(i)=(qp(i-1)*(1-lamdelz)+lamdelz*(qp(i)+qp(i-1)))/(1+lamdelz);
        qp(i)=min(qp(i),qps(i));
    end    
    Tpv=Tp.*(1+qps'./0.622)./(1+qps'+qi)-273.15;
    Tpz=Tpv-30.*log(0.001.*p);
    g3=plot(Tpz,p,'.c','markersize',12);
    legend([g1,g2,g3],'Reversible','Pseudo-adiabatic','Entraining plume')
    hold off
end
disp(' ')
disp('Hit "Enter" to continue')
pause
plot(Trowlift-Tv',p,'b',Trowliftpa-Tv',p,'r',Tpv'-Tv',p,'c','linewidth',2);
set(gca,'ylim',[100 1000])
set(gca,'ytick',1000:100:100)
set(gca,'yscale','log','ydir','reverse')
set(gca,'fontweight','bold')
set(gca,'ytick',100:100:1000)
xlabel('Buoyancy (K)')
ylabel('Pressure')
legend('Reversible wo/ice','Pseudo-adiabatic w/ice','Entraining plume w/ice','location','best')
titstring2=[titstring,'; Parcel lifted from ',char(num2str(plift(1))),' hPa']; 
title(titstring2)