%
%  This script calls Andy Rhines' routine to get a sounding from the
%  University of Wyoming and uses skewt.m to plot it. No need to visit U.
%  Wyoming seperately.
%
place=input('Enter 5-digit station ID or place name (in single quotations) ');
if max(size(place)) > 1
    [u,states,nations,status]=getids(place);
    if status == 0
        disp(' ')
        disp('No such place')
        return
    end    
    usize=max(size(u));
    if usize > 1
        disp(' ')
        disp('Possible station numbers:')
        for i=1:usize
            disp([num2str(u(i)),char(' '),char(states(i)),char(' '),char(nations(i))])
        end    
        disp(' ')
        station_id=input('Which one do you want? (5-digit identifier) ');
    else
        station_id=u;
    end
else
    station_id=place;
end    
A=input('Enter year, month, day,GMT time (e.g. [2014 7 3 0])');
year=A(1);
month=A(2);
day=A(3);
hour=A(4);
%
[data,header,status] = getsounding(station_id,year,month,day,hour);
if status == 0
    disp('No data for this station and time')
    return
end    
%
success=skewtv(data(:,1),data(:,3),data(:,5)/100);
%
titstring=['Station ',num2str(station_id),'  ',num2str(year),'/', ...
    num2str(month),'/',num2str(day),'/', num2str(hour)];
title(titstring)
%
a=10;
while a > 0
    pideal=input('Enter best pressure to reversibly lift parcel from (0 to stop)');
    if pideal < 100
        return
    end    
    if exist('g1') && ishandle(g1) %#ok<EXIST>
        delete(g1)
        delete(g2)
    end
    [~,ibest]=min(abs(data(:,1)-pideal));
    p0=data(ibest,1);
    T0=273.15+data(ibest,3);
    q0=0.001.*data(ibest,6);
    if isnan(T0) || isnan(q0)
        ibest=ibest+1;
        p0=data(ibest,1);
        if p0 < 500
            disp(' ')
            disp('Could not find viable parcel level')
            return
        end    
        T0=273.15+data(ibest,3);
        q0=0.001.*data(ibest,6);
    end
    plift=data(ibest:end,1);
    [ Tlift,qslift] = svinvert( T0,q0,p0,plift );
    Trowlift=Tlift.*(1+qslift/0.622)./(1+q0)-273.15;
    [ Tliftpa,qsliftpa] = svinvertpa( T0,q0,p0,plift );
    Trowliftpa=Tliftpa.*(1+qsliftpa/0.622)./(1+qsliftpa)-273.15;
    %
    Tz=Trowlift'-30.*log(0.001.*plift);
    Tzpa=Trowliftpa'-30.*log(0.001.*plift);
    hold on
    g1=plot(Tz,plift,'.b','markersize',12);
    g2=plot(Tzpa,plift,'--r','linewidth',1.5);
    hold off
    legend([g1,g2],'Reversible','Pseudo-adiabatic')
    titstring2=[titstring,'; Parcel lifted from ',char(num2str(plift(1))),' hPa']; 
    title(titstring2)
end