function success=skewtv(pz,tz,rhz)
%
% Calculates and displays a Skew-T diagram as a function of virtual
% temperature.
%
% pz = pressure (hPa), tz = temperature (C), rhz = relative humidity (0-1)
%
%------------------------------------------------------------------------
ez=6.112.*exp(17.67.*tz./(243.5+tz));
qz=rhz.*0.622.*ez./(pz-ez);
chi=log(pz.*qz./(6.112.*(0.622+qz)));
tdz=243.5.*chi./(17.67-chi);
%
p=1050:-25:100;
pplot=transpose(p);
t0=-48:2:50;
[ps1,ps2]=size(p);
ps=max(ps1,ps2);
[ts1,ts2]=size(t0);
ts=max(ts1,ts2);
Lvcp=2.555e3./1005;
Rdcp=287/1005;
tvem=zeros(ts,ps);
thet=zeros(ts,ps);
thetaea=zeros(ts,ps);
q=zeros(ts,ps);
for i=1:ts
   for j=1:ps
       tv=t0(i)+30.*log(0.001.*p(j));
       qg=q(i,j);
       %
       %  This iteration is to find temperature given virtual temperature
       %  
       for n=1:3
          TK=(273.15+tv).*(1+qg)./(1+qg/0.622);
          Tc=TK-273.15;
          es=6.112.*exp(17.67.*Tc./(243.5+Tc));
          qg=0.622.*es./(p(j)-es);
       end
      q(i,j)=1000*qg;
      thet(i,j)=TK.*(1000./p(j)).^Rdcp;
      thetaea(i,j)=thet(i,j).*exp(Lvcp.*q(i,j)./TK);
      thet(i,j)=thet(i,j)*(1+qg/0.622)/(1+qg);
      tvem(i,j)=tv;
   end
end
t0=transpose(t0);
temp=transpose(tvem);
theta=transpose(thet);
thetae=transpose(thetaea);
qs=transpose(sqrt(q));
[~]=contour(t0,pplot,temp,16,'k');
hold on
set(gca,'ytick',100:100:1000)
set(gca,'yscale','log','ydir','reverse')
set(gca,'fontweight','bold')
set(gca,'ytick',100:100:1000)
set(gca,'ygrid','on')
hold on
[~]=contour(t0,pplot,theta,24,'b');
[~]=contour(t0,pplot,qs,24,'g');
[~]=contour(t0,pplot,thetae,24,'r');
tvz=(tz+273.15).*(1+qz./0.622)./(1+qz)-273.15;
tzm=tvz-30.*log(0.001.*pz);
tdzm=tdz-30.*log(0.001.*pz);
h=plot(tzm,pz,'r',tdzm,pz,'g');
set(h,'linewidth',2)
hold off
xlabel('Density Temperature (C)','fontweight','bold')
ylabel('Pressure (mb)','fontweight','bold')
set(gca,'ylim',[100 1000])
success='yes';
