function [ T,qs,qip] = svinvertpai( T0,q0,p0,p )
%  This function accepts parcel temperature T0 (K), specific humidity q0,
%  (g/g),pressure p0 (hPa)
%  and a vector of pressure (hPa), and returns vectors of temperature (K),
%  and saturation specific humidity (g/g) along a pseudo-adiabat, according
%  to Bryan (2008). It has a crude representation of the ice phase as well.
%
%  Note:  This is not a very efficient algorithm
%
cp=1005;
ci=2000;
Rd=287;
Rv=461;
Lv=2.555e6;  % Optimum value from Bryan (2008)
Lf=3.34e5;
pref=1000;
Tref=290;
tolerance=0.002;
%
%  Vapor pressure, saturation vapor pressure, and entropy
%
e0=p0*q0/(0.622+q0);
Tc=T0-273.15;
if Tc > 0
    qi=0;
    es=6.112*exp(17.67*Tc/(243.5+Tc));
else
    es=exp(23.33086-6111.72784/T0+0.15215*log(T0));
    qi=0.622*(6.112/(500-6.112)-es/(p0-es));
    qi=max(qi,0);
end    
s0=(cp+ci*qi)*log(T0/Tref)-Rd*log(p0/pref)+Lv*q0/T0-Lf*qi/T0-q0*Rv*log(e0/es);
%
%   First guess
%
Tg=280;
psize=max(size(p));
T=zeros(1,psize);
qs=zeros(1,psize);
qip=zeros(1,psize);
%
for i=1:psize,
    del=10;
    n=0;
    while del > tolerance && n < 1000
        n=n+1;
        %
        Tgc=Tg-273.15;
        if Tgc > 0
            qi=0;
            es=6.112*exp(17.67*Tgc/(243.5+Tgc));
        else
            es=exp(23.33086-6111.72784/Tg+0.15215*log(Tg));
            qi=0.622*(6.112/(500-6.112)-es/(p(i)-es));
            qi=max(qi,0);
        end    
        qsg=0.622*es/(p(i)-es);
        T(i)=Tref*exp((s0+Rd*log(p(i)/pref)-Lv*qsg/Tg+Lf*qi/Tg)/(cp+ci*qi));
        del=abs(T(i)-Tg);
        Tg=0.65*Tg+0.35*T(i);
    end
    T(i)=Tg;
    qip(i)=qi;
    Tgc=Tg-273.15;
    if Tgc > 0
        es=6.112*exp(17.67*Tgc/(243.5+Tgc));
    else
        es=exp(23.33086-6111.72784/Tg+0.15215*log(Tg));
    end    
    qs(i)=0.622*es/(p(i)-es);
end
end